"""configflow - is the configuration management library for Python."""

from configflow import exceptions
from configflow import sources


__title__ = "configflow"
__summary__ = "configflow - is the configuration management library for Python."
__uri__ = "https://configflow.readthedocs.io/en/latest"

__version__ = "0.2.0"

__author__ = "Volodymyr Pivoshenko"
__email__ = "volodymyr.pivoshenko@gmail.com"

__license__ = "BSD-3-Clause"
__copyright__ = "Copyright 2022, Volodymyr Pivoshenko"

__all__ = ["sources"]
